ElementControlRequest

Enum ElementControlRequest 

pub enum ElementControlRequest {
    OpenStatusChannel {
        status_channel: ServerEnd<StatusMarker>,
        control_handle: ElementControlControlHandle,
    },
    RegisterDependencyToken {
        token: Event,
        responder: ElementControlRegisterDependencyTokenResponder,
    },
    UnregisterDependencyToken {
        token: Event,
        responder: ElementControlUnregisterDependencyTokenResponder,
    },
    AddDependency {
        dependent_level: u8,
        requires_token: Event,
        requires_level_by_preference: Vec<u8>,
        responder: ElementControlAddDependencyResponder,
    },
#[non_exhaustive]
_UnknownMethod { ordinal: u64, control_handle: ElementControlControlHandle, method_type: MethodType, }, }
Provides element-scoped access to an element previously added via Topology.AddElement.

Variants



OpenStatusChannel

Register a new Status channel on which Power Broker will send read-only updates of the element’s current power level. This method is intended to allow element owners to give read-only access to the element’s current power level to clients by opening and transferring this channel.

Fields

status_channel: ServerEnd<StatusMarker>


RegisterDependencyToken

Register a token which will permit the bearer to add either a dependency upon this element.



UnregisterDependencyToken

Unregister a token previously registered via RegisterDependencyToken.



AddDependency

Add a new dependency to an existing element. If any open leases would incorporate this dependency, the required element and any transitively required elements must complete all necessary transitions (via ElementRunner.SetLevel calls) before this method will return.

Fields

dependent_level: u8
requires_token: Event
requires_level_by_preference: Vec<u8>


#[non_exhaustive]
_UnknownMethod

An interaction was received which does not match any known method.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
ordinal: u64

Ordinal of the method that was called.

method_type: MethodType

Implementations