pub struct ElementControlProxy { /* private fields */ }Implementations
Sourceimpl ElementControlProxy
impl ElementControlProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.power.broker/ElementControl.
Sourcepub fn take_event_stream(&self) -> ElementControlEventStream
pub fn take_event_stream(&self) -> ElementControlEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn open_status_channel(
&self,
status_channel: ServerEnd<StatusMarker>,
) -> Result<(), Error>
pub fn open_status_channel( &self, status_channel: ServerEnd<StatusMarker>, ) -> Result<(), Error>
Register a new Status channel on which Power Broker will send read-only updates of the element’s current power level. This method is intended to allow element owners to give read-only access to the element’s current power level to clients by opening and transferring this channel.
Sourcepub fn register_dependency_token(
&self,
token: Event,
) -> QueryResponseFut<ElementControlRegisterDependencyTokenResult, DefaultFuchsiaResourceDialect>
pub fn register_dependency_token( &self, token: Event, ) -> QueryResponseFut<ElementControlRegisterDependencyTokenResult, DefaultFuchsiaResourceDialect>
Register a token which will permit the bearer to add either a dependency upon this element.
Sourcepub fn unregister_dependency_token(
&self,
token: Event,
) -> QueryResponseFut<ElementControlUnregisterDependencyTokenResult, DefaultFuchsiaResourceDialect>
pub fn unregister_dependency_token( &self, token: Event, ) -> QueryResponseFut<ElementControlUnregisterDependencyTokenResult, DefaultFuchsiaResourceDialect>
Unregister a token previously registered via RegisterDependencyToken.
Sourcepub fn add_dependency(
&self,
dependent_level: u8,
requires_token: Event,
requires_level_by_preference: &[u8],
) -> QueryResponseFut<ElementControlAddDependencyResult, DefaultFuchsiaResourceDialect>
pub fn add_dependency( &self, dependent_level: u8, requires_token: Event, requires_level_by_preference: &[u8], ) -> QueryResponseFut<ElementControlAddDependencyResult, DefaultFuchsiaResourceDialect>
Add a new dependency to an existing element. If any open leases would incorporate this dependency, the required element and any transitively required elements must complete all necessary transitions (via ElementRunner.SetLevel calls) before this method will return.