pub struct ElementInfoProviderGetStatusEndpointsResponse {
pub endpoints: Vec<ElementStatusEndpoint>,
}Fields
endpoints: Vec<ElementStatusEndpoint>Trait Implementations
Sourceimpl Decode<ElementInfoProviderGetStatusEndpointsResponse, DefaultFuchsiaResourceDialect> for ElementInfoProviderGetStatusEndpointsResponse
impl Decode<ElementInfoProviderGetStatusEndpointsResponse, DefaultFuchsiaResourceDialect> for ElementInfoProviderGetStatusEndpointsResponse
Sourceimpl Encode<ElementInfoProviderGetStatusEndpointsResponse, DefaultFuchsiaResourceDialect> for &mut ElementInfoProviderGetStatusEndpointsResponse
impl Encode<ElementInfoProviderGetStatusEndpointsResponse, DefaultFuchsiaResourceDialect> for &mut ElementInfoProviderGetStatusEndpointsResponse
Sourceimpl<T0: Encode<UnboundedVector<ElementStatusEndpoint>, DefaultFuchsiaResourceDialect>> Encode<ElementInfoProviderGetStatusEndpointsResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<UnboundedVector<ElementStatusEndpoint>, DefaultFuchsiaResourceDialect>> Encode<ElementInfoProviderGetStatusEndpointsResponse, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl ResourceTypeMarker for ElementInfoProviderGetStatusEndpointsResponse
impl ResourceTypeMarker for ElementInfoProviderGetStatusEndpointsResponse
Sourcetype Borrowed<'a> = &'a mut ElementInfoProviderGetStatusEndpointsResponse
type Borrowed<'a> = &'a mut ElementInfoProviderGetStatusEndpointsResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for ElementInfoProviderGetStatusEndpointsResponse
impl StructuralPartialEq for ElementInfoProviderGetStatusEndpointsResponse
Sourceimpl TypeMarker for ElementInfoProviderGetStatusEndpointsResponse
impl TypeMarker for ElementInfoProviderGetStatusEndpointsResponse
Sourcetype Owned = ElementInfoProviderGetStatusEndpointsResponse
type Owned = ElementInfoProviderGetStatusEndpointsResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for ElementInfoProviderGetStatusEndpointsResponse
impl RefUnwindSafe for ElementInfoProviderGetStatusEndpointsResponse
impl Send for ElementInfoProviderGetStatusEndpointsResponse
impl Sync for ElementInfoProviderGetStatusEndpointsResponse
impl Unpin for ElementInfoProviderGetStatusEndpointsResponse
impl UnsafeUnpin for ElementInfoProviderGetStatusEndpointsResponse
impl UnwindSafe for ElementInfoProviderGetStatusEndpointsResponse