LeaseDependency

Struct LeaseDependency 

pub struct LeaseDependency {
    pub requires_token: Option<Event>,
    pub requires_level: Option<u8>,
    pub requires_level_by_preference: Option<Vec<u8>>,
    /* private fields */
}

Fields

requires_token: Option<Event>

Must supply a token registered via the RegisterDependencyToken call of the required element’s ElementControl protocol.

requires_level: Option<u8>

Level of the element required. Most clients will want to use this, but for forward compatibility, requires_level_by_preference may be used instead.

requires_level_by_preference: Option<Vec<u8>>

Advanced Options

(Optional) For forward compatibility, the list of levels in decreasing preferential order that power broker should attempt to make required for this dependency to be satisfied. The first level in list that is a valid level will become the required level. If this is set, requires_level will be ignored.

Platform clients can use this list to keep backwards compatibility with dependencies by providing multiple levels that the dependency may have implemented in older API levels.