LeaseSchema

Struct LeaseSchema 

pub struct LeaseSchema {
    pub lease_token: Option<EventPair>,
    pub lease_name: Option<String>,
    pub dependencies: Option<Vec<LeaseDependency>>,
    pub should_return_pending_lease: Option<bool>,
    /* private fields */
}
Passed to Topology.Lease.

Fields

lease_token: Option<EventPair>

The half of an eventpair to be held by the Power Broker. The other half of the pair should be retained by the client. See LeaseToken below for more usage details.

lease_name: Option<String>

Human-readable name for logging and debug purposes.

dependencies: Option<Vec<LeaseDependency>>

List of dependencies for this lease.

should_return_pending_lease: Option<bool>

(Optional) By default, Topology.Lease will wait until the lease is SATISFIED before returning. If should_return_pending_lease is true, it will instead return as soon as the lease has been granted by Power Broker but it may still be PENDING. Clients can listen for LEASE_SIGNAL_SATISFIED to know when the lease has been SATISFIED.