pub struct TopologyLeaseResponder { /* private fields */ }Implementations
Sourceimpl TopologyLeaseResponder
impl TopologyLeaseResponder
Sourcepub fn send(self, result: Result<(), LeaseError>) -> Result<(), Error>
pub fn send(self, result: Result<(), LeaseError>) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
result: Result<(), LeaseError>,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, result: Result<(), LeaseError>, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.