pub type LeaseToken = EventPair;Expand description
A token that represents an open lease. The client’s handle should be dropped to indicate the lease should be closed. This handle may be duplicated if the lease will be shared; the lease will remain open until the last handle is dropped.
Aliased Type
pub struct LeaseToken(/* private fields */);