pub struct ElementControlSynchronousProxy { /* private fields */ }Implementations
Sourceimpl ElementControlSynchronousProxy
impl ElementControlSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<ElementControlEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<ElementControlEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn open_status_channel(
&self,
status_channel: ServerEnd<StatusMarker>,
) -> Result<(), Error>
pub fn open_status_channel( &self, status_channel: ServerEnd<StatusMarker>, ) -> Result<(), Error>
Register a new Status channel on which Power Broker will send read-only updates of the element’s current power level. This method is intended to allow element owners to give read-only access to the element’s current power level to clients by opening and transferring this channel.
Sourcepub fn register_dependency_token(
&self,
token: Event,
___deadline: MonotonicInstant,
) -> Result<ElementControlRegisterDependencyTokenResult, Error>
pub fn register_dependency_token( &self, token: Event, ___deadline: MonotonicInstant, ) -> Result<ElementControlRegisterDependencyTokenResult, Error>
Register a token which will permit the bearer to add either a dependency upon this element.
Sourcepub fn unregister_dependency_token(
&self,
token: Event,
___deadline: MonotonicInstant,
) -> Result<ElementControlUnregisterDependencyTokenResult, Error>
pub fn unregister_dependency_token( &self, token: Event, ___deadline: MonotonicInstant, ) -> Result<ElementControlUnregisterDependencyTokenResult, Error>
Unregister a token previously registered via RegisterDependencyToken.
Sourcepub fn add_dependency(
&self,
dependent_level: u8,
requires_token: Event,
requires_level_by_preference: &[u8],
___deadline: MonotonicInstant,
) -> Result<ElementControlAddDependencyResult, Error>
pub fn add_dependency( &self, dependent_level: u8, requires_token: Event, requires_level_by_preference: &[u8], ___deadline: MonotonicInstant, ) -> Result<ElementControlAddDependencyResult, Error>
Add a new dependency to an existing element. If any open leases would incorporate this dependency, the required element and any transitively required elements must complete all necessary transitions (via ElementRunner.SetLevel calls) before this method will return.